@@ -9,6 +9,7 @@ from kuyruk.manager.messaging import message_loop
 class ManagerServer(ThreadingTCPServer):
 
     daemon_threads = True
+    allow_reuse_address = True
 
     def __init__(self, host, port):
         self.clients = {}
@@ -45,7 +46,7 @@ class RequestHandler(BaseRequestHandler):
             pass
 
     def _on_stats(self, sock, stats):
-        print self.client_address, pformat(stats)
+        print 'Received stats from', self.client_address
         self.struct.stats = stats
 
     @property
