@@ -13,7 +13,7 @@ from contextlib import contextmanager
 from kuyruk import events, importer
 from kuyruk.queue import Queue
 from kuyruk.events import EventMixin
-from kuyruk.exceptions import Timeout, InvalidTask, ObjectNotFound, InvalidCall
+from kuyruk.exceptions import Timeout, InvalidTask, ObjectNotFound
 
 logger = logging.getLogger(__name__)
 
@@ -42,18 +42,16 @@ def object_to_id(f):
             try:
                 obj = args[0]
             except IndexError:
-                raise InvalidCall("You must give an instance of %s as first "
-                                  "argument." % cls)
+                msg = "You must give an instance of %s as first argument." % cls
+                raise TypeError(msg)
 
             if not isinstance(obj, cls):
-                raise InvalidCall("First argument must be an instance of %s." %
-                                  cls)
+                msg = "First argument must be an instance of %s." % cls
+                raise TypeError(msg)
 
             args = list(args)
-            try:
-                args[0] = args[0].id
-            except AttributeError:
-                raise InvalidCall("%s object must have an id attribute." % cls)
+            args[0] = args[0].id
+            assert isinstance(args[0], (int, long, basestring))
         return f(self, *args, **kwargs)
     return inner
 
@@ -72,13 +70,16 @@ def id_to_object(f):
                 raise InvalidTask
 
             obj_id = args[0]
+            if not isinstance(obj_id, (int, long, basestring)):
+                raise InvalidTask
+
             obj = cls.get(obj_id)
             if obj is None:
                 raise ObjectNotFound
 
             if not isinstance(obj, cls):
-                raise ObjectNotFound("%s is not an instance of %s." %
-                                     (obj, cls))
+                msg = "%s is not an instance of %s." % (obj, cls)
+                raise ObjectNotFound(msg)
 
             args = list(args)
             args[0] = obj
@@ -354,21 +355,23 @@ class TaskResult(object):
     def __init__(self, task):
         self.task = task
 
-    def __getattr__(self, item):
-        raise Exception(item)
+    def __getattr__(self, name):
+        raise NotImplementedError(name)
 
-    def __getitem__(self, item):
-        raise Exception(item)
+    def __setattr__(self, name, value):
+        if name not in ('task', 'id', 'result'):
+            raise NotImplementedError(name)
+        super(TaskResult, self).__setattr__(name, value)
+
+    def __getitem__(self, key):
+        raise NotImplementedError(key)
 
     def __setitem__(self, key, value):
-        raise Exception(key, value)
+        raise NotImplementedError(key)
 
     def __repr__(self):
         return "<TaskResult of %r>" % self.task.name
 
-    def __str__(self):
-        return self.__repr__()
-
 
 @contextmanager
 def time_limit(seconds):
